DATABASES = {
	'default': {
		'ENGINE': 'django.db.backends.sqlite3',
		'NAME': ':memory:',
	},
}
SECRET_KEY = 'this_is_a_test_secret_key'
INSTALLED_APPS = ['bootstrap_components']
MIDDLEWARE_CLASSES = []
